@@ -65,6 +65,12 @@ namespace ost {
 
 // future definition of ipv4 specific classes, now defines
 
+#define	INET_IPV4_ADDRESS_SIZE	16
+#define	CIDR_IPV4_ADDRESS_SIZE	32
+#define	INET_IPV6_ADDRESS_SIZE	40
+#define	CIDR_IPV6_ADDRESS_SIZE	45
+
+#define	CIDR		IPV4Cidr
 #define	InetAddress	IPV4Address
 #define	InetHostAddress	IPV4Host
 #define	InetMaskAddress	IPV4Mask
@@ -149,6 +155,183 @@ private:
 #endif
 };
 
+/**
+ * The CIDR class is used to support routing tables and validate address
+ * policies.
+ *
+ * @author David Sugar <dyfet@gnutelephony.org>
+ * @short Classless Internet Domain Routing
+ */
+class __EXPORT IPV4Cidr
+{
+protected:
+	struct in_addr netmask, network;
+
+	unsigned getMask(const char *cp);
+public:
+	/**
+	 * Get network address associated with this cidr.
+	 *
+	 * @return system binary coded address.
+	 */
+	inline struct in_addr getNetwork(void) const
+		{return network;};
+
+	/**
+	 * Get network mask associated with this cidr.
+	 *
+	 * @return system binary coded network mask.
+	 */
+	inline struct in_addr getNetmask(void) const
+		{return netmask;};
+
+	/**
+	 * Compute the broadcast address associated with this cidr.
+	 *
+	 * @return system binary coded network address.
+	 */
+	struct in_addr getBroadcast(void) const;
+
+	/**
+	 * Set the cidr from a full or partial hostname, or from an
+	 * address/mask, or a host/bits specification.
+	 *
+	 * @param cidr string to use.
+	 */
+	void set(const char *cidr);
+
+	/**
+	 * Construct a new cidr from a string.
+	 *
+	 * @param cidr string to use.
+	 */
+	IPV4Cidr(const char *cidr);
+
+	/**
+	 * Construct an empty cidr.
+	 */
+	IPV4Cidr();
+
+	/**
+	 * Construct a copy of a cidr.
+	 *
+	 * @param cidr to copy from.
+	 */
+	IPV4Cidr(IPV4Cidr &);
+
+	/**
+	 * See if a socket address is a member of this cidr's network.
+	 *
+	 * @param saddr pointer to test.
+	 * @return true if member of cidr.
+	 */
+	bool isMember(struct sockaddr *saddr);
+
+	/**
+	 * See if a low level address object is a member of this cidr's net.
+	 *
+	 * @param inaddr object to test.
+	 * @return true if member of cidr.
+	 */
+	bool isMember(struct in_addr &inaddr);
+};
+
+inline bool operator==(struct sockaddr *sa, IPV4Cidr &cidr)
+	{return cidr.isMember(sa);};
+
+inline bool operator==(struct in_addr &a, IPV4Cidr &cidr)
+	{return cidr.isMember(a);};
+
+#ifdef	CCXX_IPV6
+/**
+ * The CIDR class is used to support routing tables and validate address
+ * policies.
+ *
+ * @author David Sugar <dyfet@gnutelephony.org>
+ * @short Classless Internet Domain Routing
+ */
+class __EXPORT IPV6Cidr
+{
+protected:
+	struct in6_addr netmask, network;
+
+	unsigned getMask(const char *cp);
+public:
+	/**
+	 * Get network address associated with this cidr.
+	 *
+	 * @return system binary coded address.
+	 */
+	inline struct in6_addr getNetwork(void) const
+		{return network;};
+
+	/**
+	 * Get network mask associated with this cidr.
+	 *
+	 * @return system binary coded network mask.
+	 */
+	inline struct in6_addr getNetmask(void) const
+		{return netmask;};
+
+	/**
+	 * Compute the broadcast address associated with this cidr.
+	 *
+	 * @return system binary coded network address.
+	 */
+	struct in6_addr getBroadcast(void) const;
+
+	/**
+	 * Set the cidr from a full or partial hostname, or from a
+	 * host/bits specification.
+	 *
+	 * @param cidr string to use.
+	 */
+	void set(const char *cidr);
+
+	/**
+	 * Construct a new cidr from a string.
+	 *
+	 * @param cidr string to use.
+	 */
+	IPV6Cidr(const char *cidr);
+
+	/**
+	 * Construct an empty cidr.
+	 */
+	IPV6Cidr();
+
+	/**
+	 * Construct a copy of a cidr.
+	 *
+	 * @param cidr to copy from.
+	 */
+	IPV6Cidr(IPV6Cidr &);
+
+	/**
+	 * See if a socket address is a member of this cidr's network.
+	 *
+	 * @param saddr pointer to test.
+	 * @return true if member of cidr.
+	 */
+	bool isMember(struct sockaddr *saddr);
+
+	/**
+	 * See if a low level address object is a member of this cidr's net.
+	 *
+	 * @param inaddr object to test.
+	 * @return true if member of cidr.
+	 */
+	bool isMember(struct in6_addr &inaddr);
+};
+
+inline bool operator==(struct sockaddr *sa, IPV6Cidr &cidr)
+	{return cidr.isMember(sa);};
+
+inline bool operator==(struct in6_addr &a, IPV6Cidr &cidr)
+	{return cidr.isMember(a);};
+
+#endif
+
 /**
  *  The network name and address objects are all derived from a common 
  * IPV4Address base class. Specific classes, such as IPV4Host,
@@ -376,6 +559,9 @@ public:
  */
 class __EXPORT IPV4Host : public IPV4Address
 {
+private:
+	static IPV4Host _host_;
+
 public: 
 	/**
 	 * Create a new host address for a specific internet host.  The
