@@ -74,6 +74,8 @@ protected:
 	char *header[16];
 	MIMEItemPart *first, *last;
 
+	virtual ~MIMEMultipart();
+
 public:
 	/**
 	 * Contruct a multi-part document, and describe it's type.
@@ -118,6 +120,9 @@ public:
  */
 class __EXPORT MIMEMultipartForm : public MIMEMultipart
 {
+protected:
+	virtual ~MIMEMultipartForm();
+
 public:
 	/**
 	 * Construct a form result.  This is a MIMEMultipart of type
@@ -164,6 +169,8 @@ protected:
 	 * @param ct Content-Type to use.
 	 */
 	MIMEItemPart(MIMEMultipart *top, const char *ct);
+
+	virtual ~MIMEItemPart();
 };
 
 /**
@@ -179,6 +186,8 @@ protected:
 	const char *content;
 	const char *name;
 
+	virtual ~MIMEFormData();
+
 public:
 	/**
 	 * Stream header, Content-Disposition form-data.
