@@ -153,11 +153,41 @@ private:
 protected:
 	ost::String m_host, m_address;
 
+        /**
+         * Send http header to server.
+         *
+         * @param url base to send header to
+         * @param vars to post or use in get method
+         * @param bufsize of stream buffering to use
+         * @return success or class error
+         */
 	Error sendHTTPHeader(const char *url, const char **vars, size_t bufsize);
+
+        /**
+         * Called if stream buffer needs refilling.
+         *
+         * @return number of bytes refilled or error if < 0
+         */
 	int underflow(void);
 
+        /**
+         * Derived method for async or timed I/O function on url stream.
+         *
+         * @return number of bytes read or < 0 for error.
+         * @param buffer to read stream data into.
+         * @param len of bytes to read from stream.
+         * @param timer to wait for data in milliseconds.
+         */
 	virtual int aRead(char *buffer, size_t len, timeout_t timer);
 
+        /**
+         * Derived method for async or timed I/O function on url stream.
+         *
+         * @return number of bytes written or < 0 for error.
+         * @param buffer to write stream data from.
+         * @param len of bytes to write to stream.
+         * @param timer to wait for data in milliseconds.
+         */
 	virtual int aWrite(char *buffer, size_t len, timeout_t timer);
 
 	/**
@@ -179,14 +209,15 @@ public:
 	/**
 	 * Construct an instance of URL stream.
 	 *
-	 * @param to default timeout.
+	 * @param family protocol to use.
+	 * @param timer for default timeout on I/O operations.
 	 */
-	URLStream(Family family = IPV4, timeout_t to = 0);
+	URLStream(Family family = IPV4, timeout_t timer = 0);
 
 	/**
 	 * Line parsing with conversion.
 	 *
-	 * @return URLStream object.
+	 * @return URLStream object reference.
 	 * @param buffer to store.
 	 * @param len maximum buffer size.
 	 */
@@ -225,9 +256,9 @@ public:
 	/**
 	 * Post URL vars with post method.
 	 *
-	 * @return url error code.
-	 * @param url name of resource.
-	 * @param vars to set.
+	 * @return success or error code.
+	 * @param url name of resource being posted.
+	 * @param vars to set in post.
 	 * @param buffer size of buffer.
 	 */
 	Error post(const char *url, const char **vars, size_t buffer = 512);
@@ -235,10 +266,10 @@ public:
 	/**
 	 * Post URL with MIME multipart form.
 	 *
-	 * @return url error code.
-	 * @param url name of resource.
-	 * @param reference to multipart form.
-	 * @param size of buffer.
+	 * @return success or error code.
+	 * @param url name of resource being posted.
+	 * @param form multi-part resource.
+	 * @param buffer size to use.
 	 */
 	Error post(const char *url, MIMEMultipartForm &form, size_t buffer = 512);
 
