@@ -49,6 +49,8 @@ namespace ost {
 Mutex IPV4Address::mutex;
 #endif
 
+IPV4Host IPV4Host::_host_;
+
 const IPV4MulticastValidator IPV4Multicast::validator;
 
 void IPV4MulticastValidator::operator()(const in_addr address) const
@@ -255,8 +257,13 @@ IPV4Address(host)
 
 	if(!host)
 	{
-		gethostname(namebuf, 256);
-		setAddress(namebuf);
+		if(this == &_host_)
+		{
+			gethostname(namebuf, 256);
+			setAddress(namebuf);
+		}
+		else
+			*this = _host_;
 	}
 }
 
