@@ -471,7 +471,7 @@ int Serial::aRead(char * Data, const int Length)
     ClearCommError(dev, &dwError, &cs);
 
     // If not requiring an exact byte count, get whatever is available
-    if(dwLength > (int)cs.cbInQue)
+    if(Length > (int)cs.cbInQue)
         dwReadLength = cs.cbInQue;
     else
         dwReadLength = Length;
