@@ -518,7 +518,26 @@ Thread(pri, stack), Mutex(id)
 #ifndef WIN32
 	FD_ZERO(&connect);
 	long opt;
-	::pipe(iosync);
+	if(::pipe(iosync))
+	{
+#ifdef	CCXX_EXCEPTIONS
+		switch(Thread::getException())
+		{
+		case throwObject:
+			throw(this);
+			return;
+#ifdef	COMMON_STD_EXCEPTION
+		case throwException:
+			throw(ThrException("no service pipe"));
+			return;
+#endif
+		default:
+			return;
+		}
+#else
+		return;
+#endif
+	}
 	hiwater = iosync[0] + 1;
 	FD_SET(iosync[0], &connect);
 
@@ -620,7 +639,28 @@ void SocketService::detach(SocketPort *port)
 void SocketService::update(unsigned char flag)
 {
 #ifndef WIN32
-	::write(iosync[1], (char *)&flag, 1);
+	if(::write(iosync[1], (char *)&flag, 1) < 1)
+	{
+
+#ifdef	CCXX_EXCEPTIONS
+		switch(Thread::getException())
+		{
+		case throwObject:
+			throw(this);
+			return;
+#ifdef	COMMON_STD_EXCEPTION
+		case throwException:
+			throw(ThrException("update failed"));
+			return;
+#endif
+		default:
+			return;
+		}
+#else
+		return;
+#endif
+	}
+
 #else
 	sync->update(flag);
 #endif
