@@ -50,14 +50,6 @@
 #include <syslog.h>
 #endif
 
-#ifdef HAVE_LIBXML
-#include <libxml/xmlversion.h>
-#include <libxml/parser.h>
-#include <libxml/parserInternals.h>
-#include <libxml/xmlIO.h>
-#include <cstdarg>
-#endif
-
 // very ugly, but saves a lot of #ifdefs. To understand this, look at
 // the private members of XMLRPC.
 #ifndef HAVE_SSTREAM
@@ -80,45 +72,6 @@ using std::ends;
 using std::ios;
 #endif
 
-#ifdef	HAVE_LIBXML
-extern "C" {
-
-static void saxCharacters(XMLStream *xml, const unsigned char *text, int unsigned len)
-{
-	xml->characters(text, len);
-}
-
-static void saxComment(XMLStream *xml, const unsigned char *text)
-{
-	unsigned len = strlen((const char *)text);
-	xml->comment(text, len);
-}
-
-static void saxStartDocument(XMLStream *xml)
-{
-	xml->startDocument();
-}
-
-static void saxEndDocument(XMLStream *xml)
-{
-	xml->endDocument();
-}
-
-static void saxStartElement(XMLStream *xml, const unsigned char *name, const unsigned char **attributes)
-{
-	xml->startElement(name, attributes);
-}
-
-static void saxEndElement(XMLStream *xml, const unsigned char *name)
-{
-	xml->endElement(name);
-}
-
-}
-#endif
-
-#ifndef	HAVE_LIBXML
-
 static bool isElement(char c)
 {
 	return isalnum(c) || c == ':' || c == '-' || c == '.' || c == '_';
@@ -153,7 +106,7 @@ bool XMLStream::parseTag(void)
 {
 	size_t len = dp;
 	const char *data = dbuf;
-	bool end = false, first = false;
+	bool end = false;
 	const unsigned char *attrib[128];
 	unsigned attr = 0;
 	char *ep;
@@ -415,15 +368,9 @@ bool XMLStream::parseChunk(const char *data, size_t len)
 	return true;
 }
 
-#endif
-
 bool XMLStream::parse(const char *resource)
 {
 	bool ret = false;
-#ifdef	HAVE_LIBXML
-	xmlParserCtxtPtr xml;
-	xmlSAXHandler sax;
-#endif
 	char buffer[1024];
 	int res;
 
@@ -431,37 +378,10 @@ bool XMLStream::parse(const char *resource)
 		if(!open(resource))
 			return false;
 
-#ifdef	HAVE_LIBXML
-	memset(&sax, 0, sizeof(sax));
-	sax.startDocument = (startDocumentSAXFunc)&saxStartDocument;
-	sax.endDocument = (endDocumentSAXFunc)&saxEndDocument;
-	sax.startElement = (startElementSAXFunc)&saxStartElement;
-	sax.endElement = (endElementSAXFunc)&saxEndElement;
-	sax.characters = (charactersSAXFunc)&saxCharacters;
-	sax.comment = (commentSAXFunc)&saxComment;
-
-	xml = xmlCreatePushParserCtxt(&sax, this, NULL, 0, NULL);
-
-	if(!xml)
-		return false;
-#else
 	parseInit();
-#endif
 
-#ifdef	HAVE_LIBXML
-	while((res = read((unsigned char *) buffer, 1024)))
-		xmlParseChunk(xml, buffer, res, 0);
-	xmlParseChunk(xml, buffer, 0, 1);
-
-	if(xml->wellFormed)
-		ret = true;
-
-	xml->sax = NULL;
-	xmlFreeParserCtxt(xml);
-#else
 	while((res = read((unsigned char *)buffer, 1024)))
 		ret = parseChunk(buffer, res);
-#endif
 	return ret;
 }
 
